grib2io.tables.section4_discipline4 API documentation

# grib2io.tables.section4_discipline4

View Source

      1table_4_2_4_0  = {
      2'0':['Temperature','K','TMPSWP'],
      3'1':['Electron Temperature','K','ELECTMP'],
      4'2':['Proton Temperature','K','PROTTMP'],
      5'3':['Ion Temperature','K','IONTMP'],
      6'4':['Parallel Temperature','K','PRATMP'],
      7'5':['Perpendicular Temperature','K','PRPTMP'],
      8'6-191':['Reserved','unknown','unknown'],
      9'192-254':['Reserved for Local Use','unknown','unknown'],
     10'255':['Missing','unknown','unknown'],
     11}
     12table_4_2_4_1  = {
     13'0':['Velocity Magnitude (Speed)','m s-1','SPEED'],
     14'1':['1st Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL1'],
     15'2':['2nd Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL2'],
     16'3':['3rd Vector Component of Velocity  (Coordinate system dependent)','m s-1','VEL3'],
     17'4-191':['Reserved','unknown','unknown'],
     18'192-254':['Reserved for Local Use','unknown','unknown'],
     19'255':['Missing','unknown','unknown'],
     20}
     21table_4_2_4_2  = {
     22'0':['Particle Number Density','m-3','PLSMDEN'],
     23'1':['Electron Density','m-3','ELCDEN'],
     24'2':['Proton Density','m-3','PROTDEN'],
     25'3':['Ion Density','m-3','IONDEN'],
     26'4':['Vertical Electron Content','m-2','VTEC'],
     27'5':['HF Absorption Frequency','Hz','ABSFRQ'],
     28'6':['HF Absorption','dB','ABSRB'],
     29'7':['Spread F','m','SPRDF'],
     30'8':['hF','m','HPRIMF'],
     31'9':['Critical Frequency','Hz','CRTFRQ'],
     32'10':['Maximal Usable Frequency (MUF)','Hz','MAXUFZ'],
     33'11':['Peak Height (hm)','m','PEAKH'],
     34'12':['Peak Density','m-3','PEAKDEN'],
     35'13':['Equivalent Slab Thickness (tau)','km','EQSLABT'],
     36'14-191':['Reserved','unknown','unknown'],
     37'192-254':['Reserved for Local Use','unknown','unknown'],
     38'255':['Missing','unknown','unknown'],
     39}
     40table_4_2_4_3  = {
     41'0':['Magnetic Field Magnitude','T','BTOT'],
     42'1':['1st Vector Component of Magnetic Field','T','BVEC1'],
     43'2':['2nd Vector Component of Magnetic Field','T','BVEC2'],
     44'3':['3rd Vector Component of Magnetic Field','T','BVEC3'],
     45'4':['Electric Field Magnitude','V m-1','ETOT'],
     46'5':['1st Vector Component of Electric Field','V m-1','EVEC1'],
     47'6':['2nd Vector Component of Electric Field','V m-1','EVEC2'],
     48'7':['3rd Vector Component of Electric Field','V m-1','EVEC3'],
     49'8-191':['Reserved','unknown','unknown'],
     50'192-254':['Reserved for Local Use','unknown','unknown'],
     51'255':['Missing','unknown','unknown'],
     52}
     53table_4_2_4_4  = {
     54'0':['Proton Flux (Differential)','(m2 s sr eV)-1','DIFPFLUX'],
     55'1':['Proton Flux (Integral)','(m2 s sr)-1','INTPFLUX'],
     56'2':['Electron Flux (Differential)','(m2 s sr eV)-1','DIFEFLUX'],
     57'3':['Electron Flux (Integral)','(m2 s sr)-1','INTEFLUX'],
     58'4':['Heavy Ion Flux (Differential)','(m2 s sr eV / nuc)-1','DIFIFLUX'],
     59'5':['Heavy Ion Flux (iIntegral)','(m2 s sr)-1','INTIFLUX'],
     60'6':['Cosmic Ray Neutron Flux','h-1','NTRNFLUX'],
     61'7-191':['Reserved','unknown','unknown'],
     62'192-254':['Reserved for Local Use','unknown','unknown'],
     63'255':['Missing','unknown','unknown'],
     64}
     65table_4_2_4_5  = {
     66'0':['Amplitude','rad','AMPL'],
     67'1':['Phase','rad','PHASE'],
     68'2':['Frequency','Hz','FREQ'],
     69'3':['Wavelength','m','WAVELGTH'],
     70'4-191':['Reserved','unknown','unknown'],
     71'192-254':['Reserved for Local Use','unknown','unknown'],
     72'255':['Missing','unknown','unknown'],
     73}
     74table_4_2_4_6  = {
     75'0':['Integrated Solar Irradiance','W m-2','TSI'],
     76'1':['Solar X-ray Flux (XRS Long)','W m-2','XLONG'],
     77'2':['Solar X-ray Flux (XRS Short)','W m-2','XSHRT'],
     78'3':['Solar EUV Irradiance','W m-2','EUVIRR'],
     79'4':['Solar Spectral Irradiance','W m-2 nm-1','SPECIRR'],
     80'5':['F10.7','W m-2 Hz-1','F107'],
     81'6':['Solar Radio Emissions','W m-2 Hz-1','SOLRF'],
     82'7-191':['Reserved','unknown','unknown'],
     83'192-254':['Reserved for Local Use','unknown','unknown'],
     84'255':['Missing','unknown','unknown'],
     85}
     86table_4_2_4_7  = {
     87'0':['Limb Intensity','m-2 s-1','LMBINT'],
     88'1':['Disk Intensity','m-2 s-1','DSKINT'],
     89'2':['Disk Intensity Day','m-2 s-1','DSKDAY'],
     90'3':['Disk Intensity Night','m-2 s-1','DSKNGT'],
     91'4-191':['Reserved','unknown','unknown'],
     92'192-254':['Reserved for Local Use','unknown','unknown'],
     93'255':['Missing','unknown','unknown'],
     94}
     95table_4_2_4_8  = {
     96'0':['X-Ray Radiance','W sr-1 m-2','XRAYRAD'],
     97'1':['EUV Radiance','W sr-1 m-2','EUVRAD'],
     98'2':['H-Alpha Radiance','W sr-1 m-2','HARAD'],
     99'3':['White Light Radiance','W sr-1 m-2','WHTRAD'],
    100'4':['CaII-K Radiance','W sr-1 m-2','CAIIRAD'],
    101'5':['White Light Coronagraph Radiance','W sr-1 m-2','WHTCOR'],
    102'6':['Heliospheric Radiance','W sr-1 m-2','HELCOR'],
    103'7':['Thematic Mask','Numeric','MASK'],
    104'8-191':['Reserved','unknown','unknown'],
    105'192-254':['Reserved for Local Use','unknown','unknown'],
    106'255':['Missing','unknown','unknown'],
    107}
    108table_4_2_4_9  = {
    109'0':['Pedersen Conductivity','S m-1','SIGPED'],
    110'1':['Hall Conductivity','S m-1','SIGHAL'],
    111'2':['Parallel Conductivity','S m-1','SIGPAR'],
    112'3-191':['Reserved','unknown','unknown'],
    113'192-254':['Reserved for Local Use','unknown','unknown'],
    114'255':['Missing','unknown','unknown'],
    115}